// ===========================================================================
// CONTENT  : ABSTRACT CLASS AActionPlugin
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 08/03/2006
// HISTORY  :
//  08/03/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.cda.ui.xpi ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.Locale;

import org.pfsw.odem.IExplorationModelObject;
import org.pfsw.tools.cda.xpi.APluginImplementation;

/**
 * The purpose of this abstract plugin implementation is to provide default
 * implementations of methods that may be overridden by subclasses.
 * This is more stable in comparison to an interface, since adding new
 * methods won't break already existing subclasses.
 * <p>
 * All subclasses must implement a public non-argument constructor!
 *
 * @author M.Duchrow
 * @version 1.0
 */
abstract public class AActionPlugin extends APluginImplementation implements IPluginActionInfo
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
	/**
	 * Returns the text that should be shown as tooltip for this plug-in.
	 * Subclasses should override this method to provide a localized text for
	 * a short description of their plug-in functionality.
	 * <br>
	 * The default implementation returns null.
	 * 
	 * @param locale Represents the language the text is required for
	 * @param object An object from the data model CDA is working on
	 * @return A text or null to indicate that there is no tooltip text
	 */
	@Override
  public String getToolTipText( Locale locale, IExplorationModelObject object  ) 
	{
		return null ;
	} // getToolTipText() 
	
	// -------------------------------------------------------------------------
	
	/**
	 * Returns the filename of an icon image to that should be shown if the 
	 * plug-in can be used.
	 * The default implementation returns null.
	 * 
	 * @param object An object from the data model CDA is working on
	 * @return An filename of a graphics file or null 
	 */
	@Override
  public String getEnabledIconFilename( IExplorationModelObject object ) 
	{
		return null ;
	} // getEnabledIconFilename() 
	
	// -------------------------------------------------------------------------
	
	/**
	 * Returns the name of an icon file that should be shown in the UI when the 
	 * plug-in cannot be used.
	 * The default implementation returns null.
	 * 
	 * @param object An object from the data model CDA is working on
	 * @return An filename of a graphics file or null 
	 */
	@Override
  public String getDisabledIconFilename( IExplorationModelObject object ) 
	{
		return null ;
	} // getDisabledIconFilename() 
	
	// -------------------------------------------------------------------------
	
} // class AActionPlugin 
